.slide.cycle-slide {
  max-width: 100%;
  overflow: hidden;
}
.slide.cycle-slide > a {
  line-height: 0;
}
/* Prev/Next arrows */
.cycle-prev, .cycle-next {
  cursor: pointer;
  height: 100%;
  opacity: 0.7;
  position: absolute;
  top: 0;
  width: 25%;
  z-index: 110;
}
.cycle-prev {
    background: url("++resource++covertile.cycle2/prev-arrow.png") no-repeat scroll 10% 50% rgba(0, 0, 0, 0);
    left: 0;
}
.cycle-next {
    background: url("++resource++covertile.cycle2/next-arrow.png") no-repeat scroll 90% 50% rgba(0, 0, 0, 0);
    right: 0;
}
.cycle-prev:hover, .cycle-next:hover {
    opacity: 1;
}
a.edit-tile-link {
  z-index: 150;
}
.cycle-pager-container {
  position: absolute;
  top: 0;
  width: 100%;
  z-index: 110;
  text-align: center;
}
.cycle-pager {
  display: inline-block;
  margin: 0 auto;
  padding: 8px;
}
.cycle-pager span {
  background: url("++resource++covertile.cycle2/dot.png") no-repeat;
  display: inline-block;
  font-size: 0;
  height: 16px;
  opacity: 0.6;
  width: 16px;
}
.cycle-pager > span {
  cursor: pointer;
}
.cycle-pager .cycle-pager-active {
  opacity: 1;
}
.cycle-pager-container.thumbnails_square .cycle-pager {
  background: white;
}
.cycle-pager-container.thumbnails_square .cycle-pager img {
  border-radius: 5px;
  margin-right: 8px;
}
.cycle-pager-container.thumbnails_square .cycle-pager a:last-child img {
  margin-right: 0;
}
.cycle-pager-container.numbers .cycle-pager {
  background-color: #222;
  opacity: 0.6;
}
#content .cycle-pager-container.numbers a:link {
  color: white;
  font-size: 1.25em;
  padding: 0 0.25em;
}
.cycle-caption {
  color: white;
  position: absolute;
  top: 15px;
  right: 15px;
  z-index: 120;
}
.cycle-overlay {
  background: none repeat scroll 0 0 black;
  bottom: 0;
  color: white;
  opacity: 0.5;
  padding: 15px 0;
  position: absolute;
  width: 100%;
  z-index: 120;
}
.cycle-overlay > div {
  padding: 0 15px;
}
/* Stop overlay being bigger than slides */
.slide.cycle-sentinel {
  min-height: 6em;
}
.contentActions {
  z-index: 130;
}
/* Hide Image position widget & Image visibility widget */
#formfield-covertile-cycle2-carousel-image .visibility-box,
#covertile-cycle2-carousel-image-imgsize + span,
#covertile-cycle2-carousel-image-position {
  display: none;
}

/* Stop Flash of unstyled content */
.covertile-cycle2 .slide {
  display: none;
}

.covertile-cycle2 .cycle-pager + .slide {
  display: block;
}
/* Stops pagers being misplaced when multiple carousel tiles on page */
.tile {
  position: relative;
}
